@@ -1,11 +1,11 @@
 var group__spa__node =
 [
-    [ "command.h", "node_2command_8h.html", null ],
-    [ "event.h", "node_2event_8h.html", null ],
+    [ "node/command.h", "node_2command_8h.html", null ],
+    [ "node/event.h", "node_2event_8h.html", null ],
     [ "io.h", "io_8h.html", null ],
-    [ "keys.h", "spa_2include_2spa_2node_2keys_8h.html", null ],
-    [ "node.h", "spa_2include_2spa_2node_2node_8h.html", null ],
-    [ "type-info.h", "node_2type-info_8h.html", null ],
+    [ "spa/include/spa/node/keys.h", "spa_2include_2spa_2node_2keys_8h.html", null ],
+    [ "spa/include/spa/node/node.h", "spa_2include_2spa_2node_2node_8h.html", null ],
+    [ "node/type-info.h", "node_2type-info_8h.html", null ],
     [ "spa_io_buffers", "structspa__io__buffers.html", [
       [ "status", "structspa__io__buffers.html#a1364df7bc201533525e5a4fa54f444fe", null ],
       [ "buffer_id", "structspa__io__buffers.html#aadfe10a114c998d88137450877d8326b", null ]
@@ -30,7 +30,10 @@ var group__spa__node =
       [ "delay", "structspa__io__clock.html#af8fa38eef9a514c13306bd01da06e776", null ],
       [ "rate_diff", "structspa__io__clock.html#aaddd01ce3e78da42c39efdeab2180035", null ],
       [ "next_nsec", "structspa__io__clock.html#a3242b88552347adc2e406b75f8136060", null ],
-      [ "padding", "structspa__io__clock.html#af53218491c71ee19db11966bb16269ce", null ]
+      [ "target_rate", "structspa__io__clock.html#a02274245ac560717fc5c06ddc66553ff", null ],
+      [ "target_duration", "structspa__io__clock.html#ad5f6c0254efd87a20ca5807b577d3473", null ],
+      [ "target_seq", "structspa__io__clock.html#af91526e984d8c9453e8b98c12dd1f500", null ],
+      [ "padding", "structspa__io__clock.html#ade3b0ef4306272d9a83a361ac3312cad", null ]
     ] ],
     [ "spa_io_video_size", "structspa__io__video__size.html", [
       [ "flags", "structspa__io__video__size.html#ab8f1361af870dd5de789b63b687a22ce", null ],
@@ -185,6 +188,7 @@ var group__spa__node =
     [ "SPA_KEY_PORT_NAME", "group__spa__node.html#gacda7725d41e954d4c5217ba95c447a69", null ],
     [ "SPA_KEY_PORT_ALIAS", "group__spa__node.html#ga9537506ba9e8517d27353be72d3e82b6", null ],
     [ "SPA_KEY_PORT_MONITOR", "group__spa__node.html#gae091e85290ec8a7578f48c2b5a73affe", null ],
+    [ "SPA_KEY_PORT_IGNORE_LATENCY", "group__spa__node.html#gad0584e7a902df3de92b8c2be0aa2ff53", null ],
     [ "SPA_TYPE_INTERFACE_Node", "group__spa__node.html#ga5c57b4fb1d72db0725992bd91b858dd6", null ],
     [ "SPA_VERSION_NODE", "group__spa__node.html#ga856b63143b916ed8de520b98e46a18ce", null ],
     [ "SPA_NODE_CHANGE_MASK_FLAGS", "group__spa__node.html#ga6dc4d1bbfffa9f49d18168d5a8302459", null ],
@@ -247,6 +251,7 @@ var group__spa__node =
     [ "SPA_NODE_METHOD_NUM", "group__spa__node.html#gaf9f1bf717bf713b7c019934218c05a5c", null ],
     [ "SPA_VERSION_NODE_METHODS", "group__spa__node.html#gaee7d45b6819789bde3de86d9be592a3a", null ],
     [ "spa_node_method", "group__spa__node.html#gaf6acc77e506b002f4af0ecd03e29c6ff", null ],
+    [ "spa_node_method_fast", "group__spa__node.html#ga3ad11e9ae12a8d68f35fa708e0fca6d5", null ],
     [ "spa_node_add_listener", "group__spa__node.html#ga594ac9d44ca70f66f42b9deb408f0e51", null ],
     [ "spa_node_set_callbacks", "group__spa__node.html#gafc6f880a7906ab6ad837b753b6c2de05", null ],
     [ "spa_node_sync", "group__spa__node.html#gabb7d0304d2f9952bcf6b95041573c2a4", null ],
@@ -261,7 +266,9 @@ var group__spa__node =
     [ "spa_node_port_use_buffers", "group__spa__node.html#gaf7f6bdf00d83c8aaa4cb13c983ff3ff6", null ],
     [ "spa_node_port_set_io", "group__spa__node.html#ga8c921a18a870cfc3163861b4fb7df6b1", null ],
     [ "spa_node_port_reuse_buffer", "group__spa__node.html#ga78928697897c91bedd278b7ab72e8380", null ],
+    [ "spa_node_port_reuse_buffer_fast", "group__spa__node.html#ga9daa5c8e89a00eb95ba4571693cd1694", null ],
     [ "spa_node_process", "group__spa__node.html#ga9d4577c9ba65dce198293c8b777ae874", null ],
+    [ "spa_node_process_fast", "group__spa__node.html#ga06f7bd68dcac9beb014db111b4e64b33", null ],
     [ "SPA_TYPE_INFO_IO", "group__spa__node.html#ga307753db51558b08071e4f2822228672", null ],
     [ "SPA_TYPE_INFO_IO_BASE", "group__spa__node.html#gaa8e30ee6ab74de00871c610bad6eeaf8", null ],
     [ "SPA_TYPE_INFO_NodeEvent", "group__spa__node.html#ga5716dde5392df4653ff81188fc6ed47e", null ],
